******
* This script configures the Stata library environment and displays the value of system parameters
******

* The local macro ProjectDir must point to the folder path that includes the /scripts folder
local ProjectDir "$Longevity"

cap assert !mi("`ProjectDir'")
if _rc {
	noi di as error "Error: need to define project directory in scripts/programs/_config.do"
	error 9
}

* Ensure Stata uses only local libraries and programs
tokenize `"$S_ADO"', parse(";")
while `"`1'"' != "" {
  if `"`1'"'!="BASE" cap adopath - `"`1'"'
  macro shift
}
adopath ++ "`ProjectDir'/scripts/libraries/stata"
adopath ++ "`ProjectDir'/scripts/programs"

* Display system parameters and record the date and time
cap program drop _print_timestamp 
program define _print_timestamp 
	di "{hline `=min(79, c(linesize))'}"

	di "Date and time: $S_DATE $S_TIME"
	di "Stata version: `c(stata_version)'"
	di "Updated as of: `c(born_date)'"
	di "Variant:       `=cond( c(MP),"MP",cond(c(SE),"SE",c(flavor)) )'"
	di "Processors:    `c(processors)'"
	di "OS:            `c(os)' `c(osdtl)'"
	di "Machine type:  `c(machine_type)'"
	local hostname : env HOSTNAME
	if !mi("`hostname'") di "Hostname:      `hostname'"
	
	di "{hline `=min(79, c(linesize))'}"
end
noi _print_timestamp

* Additional code you want automatically executed
version 18
set varabbrev off

cap mkdir "`ProjectDir'/scripts/logs"
cap mkdir "`ProjectDir'/processed"
cap mkdir "`ProjectDir'/results"
cap mkdir "`ProjectDir'/results/intermediate"
cap mkdir "`ProjectDir'/results/figures"
cap mkdir "`ProjectDir'/results/tables"

** EOF
